@@ -1,3 +1,4 @@
+## two instances of assign replaced by justDoIt
 Menu.bbd <- function(){
 initializeDialogDoE(title=gettextRcmdr("Create Box-Behnken design ..."))   
      ## function initializeDialogDoE assumes topdes2 as windowname
@@ -126,7 +127,10 @@ onOK <- function(){
         hilfatt$creator <- .stored.designbbd
         class(hilfatt$creator) <- c("menu.designbbd", "list")
         attr(hilf, "design.info") <- hilfatt
-        assign(name, hilf, envir=.GlobalEnv)
+        putRcmdr("hilf", hilf)
+        ## replace assign by justDoIt; assign(name, hilf, envir=.GlobalEnv)
+        justDoIt(paste(name, "<- getRcmdr(\"hilf\")"))
+        rm("hilf", pos="RcmdrEnv")
         activeDataSet(name)
     ### exporting
     if (!tclvalue(etyperbVariable)=="none"){
@@ -245,7 +249,8 @@ onStore <- function(){
              }
           }
         storeRcmdr()
-        assign(savename.RcmdrPlugin.DoE, getRcmdr(".stored.designbbd"), envir=.GlobalEnv)
+        ## replace assign by justDoIt; assign(savename.RcmdrPlugin.DoE, getRcmdr(".stored.designbbd"), envir=.GlobalEnv)
+        justDoIt(paste(savename.RcmdrPlugin.DoE, "<- getRcmdr(\".stored.designbbd\")"))
         message(gettextRcmdr("inputs have been stored"))
         }
 }
